function acV=AlgorithmicComplexityHisPro(xV,bV)
% acV = AlgorithmicComplexityHisPro(xV,bV)
% ALGORITHMICCOMPLEXITYHISPRO computes the algorithmic complexity on the
% time series 'xV'. The estimation of the algorithmic complexity is based
% on 'b' partitions of 'xV' with same probability. 
% A number of different 'b' can be given in the input vector 'bV'.
% INPUT
% - xV      : a vector for the time series
% - bV      : a vector of the number of equiprobable partitions. 
% OUTPUT
% - acV     : the vector of the algorithmic complexity values for the given
%             delays. 

n = length(xV);
if nargin==1
    bV = round(sqrt(n/5));
end
bV(bV==0) = round(sqrt(n/5));

nb = length(bV);
xmin=min(xV);
xrange=range(xV);
acV = NaN*ones(nb,1);
for ib=1:nb
    parxM = [];
    cel=[];
    b = bV(ib);
    if n<2*b
        break;
    end
    if b==1
        continue;
    end
    dV=quantile(xV,[0:1/b:1]);
    dV(1)=dV(1)-xrange*10^(-6);
    dV(end)=dV(end)+xrange*10^(-6);
    for i=1:b
        parxM(i,:)=i*(xV>=dV(i) & xV<dV(i+1));
    end
    symb=sum(parxM);
    symbc=char(symb+64);
    oo=max(symb);
    cel{1}=symbc(1);
    i=2;
    while i~=n+1
        pro=symbc(i);
        while sum(ismember(cel,pro))~=0 & i~=n
            i=i+1;
            prot=symbc(i);
            pro=[pro prot];
        end
        cel=union(cel,pro);
        if i~=n+1
           i=i+1;
        end
    end
    dic=length(cel);
    acV(ib)=(dic*log10(n))/(log10(b)*n);
end
   