function [EbandV,errormsg] = EnergyBand2(freqV,psV,bandM,leftcutoff)
% [EbandV,errormsg] = EnergyBand2(freqV,psV,bandM,leftcutoff)
% ENERGYBAND2 computes the energy in the frequency band given by 'bandM' 
% when the frequency and power spectrum are given in 'freqV' and 'psV'. 
% The lower frequency is given by 'leftcutoff'. The energy in the 
% given frequency band is simply the fraction of the sum of the values of 
% the power spectrum at the discrete frequencies within the band to the
% energy over the entire frequency band (constraint left by 'leftcutoff').
% A number of 'k' bands can be given in a 'k'x2 matrix 'bandM'. 
% INPUT 
% - freqV   : the frequencies for which the power spectrum is evaluated.
% - psV     : the power spectrum. 
% - bandM   : a k x 2 matrix where k bands are given with the left and
%             right limit in the first and second column, respectively.
% - leftcutoff: the left cutoff of frequency (to avoid the effect of drifts 
%               in the signal).
% OUTPUT
% - EbandV   : a k x 1 vector of the energy in the k bands.
% - errormsg: a string of error message in case output cannot be generated.

if nargin==3
    leftcutoff = 0;
end
errormsg = [];
[k,tmp]=size(bandM);
if tmp~=2 
    errormsg = 'Wrong format of the input for the frequency bands.';
end
nband=size(bandM,1);
EbandV = NaN*ones(nband,1);
if length((find(isnan(psV))))==0
    totalenergy = sum(psV(find(freqV>=leftcutoff)));
    for i=1:nband
        EbandV(i)=sum(psV(find(freqV>=bandM(i,1) & freqV<=bandM(i,2))))/totalenergy;
    end
else
    errormsg = 'The given periodogram contains NaN values.';
end
