function zM = FourierTransform(xV,nsur)
% zM = FourierTransform(xV,nsur)
% FOURIERTRANSFORM generates a given number of Fourier Transform (FT) 
% surrogates for the given time series 'xV'. FT suggests that the phases of
% the Fourier transform of 'xV' are randomized and the inverse Fourier 
% transform gives the surrogate time series.
% INPUT
% - xV  : the given time series
% - nsur: the number of surrogate time series (default is 1)
% OUTPUT
% - zM  : the n x nsur matrix of 'nsur' FT surrogate time series

if nargin==1
    nsur=1;
end
n=length(xV);
if rem(n,2) == 0
    n2 = n/2;
else
    n2 = (n-1)/2;
end
nfreq = n2;  
fxV = fft(xV,2*nfreq);
magnV = abs(fxV);
% The magnitudes of the Fourier transform
mV = [magnV(1:nfreq+1)' flipud(magnV(2:nfreq))']';
fiV = angle(fxV);
zM = NaN*ones(n,nsur);
for isur=1:nsur
    % The random phases
    rfiV = rand(nfreq-1,1) * 2 * pi;
    nfiV = [0; rfiV; fiV(nfreq+1); -flipud(rfiV)];
    fzV = mV .* exp(nfiV .* i); 
    % The inverse transform
    zM(:,isur)=real(ifft(fzV,n));
end
