function [yM,lagV] = LagDifference(xV,lagV)
% yV = LagDifference(xV,lagV)
% LAGDIFFERENCE takes a time series 'xV' and computes the time series 'yV'
% of the differences at given lags in 'lagV', i.e. y(t)=x(t)-x(t-lag),
% t=lag+1,...n, where 'n' is the length of 'xV' and 'lag' is a component of
% 'lagV'. 
% INPUTS:
% - xV      : vector of a scalar time series
% - lagV    : vector of lags (can be a single lag as well)
% OUTPUTS:
% - yM      : a matrix of the lag differenced time series.
% - lagV    : the vector of valid lags (in case given lags are <=0)

xV = xV(:);
n = length(xV);
lagV = lagV(lagV>0 & lagV<n/2);
if isempty(lagV) 
    yM=[];
else
    nlag = length(lagV);
    yM = NaN*ones(n,nlag);
    for ilag=1:nlag
        yM(1:n-lagV(ilag),ilag) = xV(lagV(ilag)+1:n)-xV(1:n-lagV(ilag));
    end
end
