function [MedFreq,errormsg] = MedianFrequency2(freqV,psV,leftcutoff,rightcutoff)
% [MedFreq,errormsg] = MedianFrequency2(freqV,psV,leftcutoff,rightcutoff)
% MEDIANFREQUENCY computes the median frequency in a frequency range given 
% by 'leftcutoff' and 'rightcuroff' when the frequency and power spectrum 
% are given in 'freqV' and 'psV'.. 
% It is supposed that the power spectrum is computed for frequency=1, so 
% that the largest frequency is 0.5 if 'rightcuroff' is not specified. 
% The lower frequency is given by 'leftcutoff' or 0 if 'leftcutoff' is not 
% specified. 
% INPUT 
% - freqV   : the frequencies for which the power spectrum is evaluated.
% - psV     : the power spectrum. 
% - leftcutoff: the left cutoff of frequency (to avoid the effect of drifts 
%               in the signal).
% - rightcutoff: the right cutoff of frequency (to avoid the effect of  
%                high frequency elements in the signal).
% OUTPUT
% - MedFreq : The median frequency
% - errormsg: a string of error message in case output cannot be generated.

if nargin==3
    rightcutoff = 0.5;
elseif nargin==2
    rightcutoff = 0.5;
    leftcutoff = 0.0;
end
errormsg = [];
MedFreq = [];
if length((find(isnan(psV))))==0
    d=length(psV(find(freqV<leftcutoff)));
    op=find(cumsum(psV(find(freqV>=leftcutoff)))>0.5*sum(psV(find(freqV>=leftcutoff & freqV<=rightcutoff))));
    if length(op)>0
        MedFreq=freqV(op(1)+d);
    end
else
    errormsg = 'The periodogram could not be computed or cutoff values are not proper.';
end
