function [pautV] = PartialAutocorrelation(xV,tauV)
% [pautV] = PartialAutocorrelation(xV,tauV)
% PARTIALAUTOCORRELATION computes the partial autocorrelation on the time
% series 'xV' for given delays in 'tauV'.
% INPUT
% - xV      : a vector for the time series
% - tauV    : a vector of the delays to be evaluated for
% OUTPUT
% - pauV    : the vector of the partial autocorrelations for the given delays

tauV = sort(tauV);
ntau = length(tauV);
taumax = tauV(end);
n = length(xV);
if n<taumax+1
    return;
end
xM = NaN*ones(n-taumax,taumax);
for i=1:taumax
    xM(i+1:n,i)=xV(1:n-i);
end
pautV = NaN*ones(ntau,1);
for itau=1:ntau
    tau = tauV(itau);
    [Q,R]=qr([ones(n-tau,1) xM(tau+1:n,1:tau)],0);
    bV =  R\(Q'*xV(tau+1:n));
    pautV(itau) = bV(end);
end
