function [yM,poldegreeV] = PolynomialDetrend(xV,poldegreeV)
% yV = PolynomialDetrend(xV,poldegree)
% POLYNOMIALDETREND takes a time series 'xV' and fits polynomials of 
% given degree in 'poldegreeV'. The residual time series of the fits are
% given to the output as the detrended time series. 
% INPUTS:
% - xV      : vector of a scalar time series
% - poldegreeV : vector of polynomial degrees (can be a single degree as well)
% OUTPUTS:
% - yM      : a matrix of the detrended time series.
% - poldegreeV : the vector of valid polynomial degrees (in case given degrees are <=0)

xV = xV(:);
n = length(xV);
poldegreeV = poldegreeV(poldegreeV>=0 & poldegreeV<n/2);
if isempty(poldegreeV) 
    yM=[];
else
    npoldegree = length(poldegreeV);
    yM = NaN*ones(n,npoldegree);
    for ipoldegree=1:npoldegree
        poldegree=poldegreeV(ipoldegree);
        if poldegree==0
            yM(:,ipoldegree) = xV-mean(xV);
        else
            parV = polyfit([1:n]',xV,poldegree);
            yM(:,ipoldegree) = xV - polyval(parV,[1:n]');
        end
    end
end
