function [xnorV,NnorV] = histnorm(xV,xxV)
% [NxV,xxV,yvalV] = histnorm(xV,bins)
% HISTNORM gives the x values and count values for the normal curve that
% fits the histogram of the data in 'xV' given by 'xxV' for the selected
% bins.
% INPUT
% - xV      : vector of data
% - xxV     : array of the centers of bins of xV
% OUTPUT
% - xnorV   : array of x values spread in the range of xV
% - NnorV   : array of the values for normal distribution regarding xnorV
nresol = 1000;

n = length(xV);
mx = mean(xV);
sdx = std(xV);

xnorV = linspace(mx-4*sdx,mx+4*sdx,nresol);
fnorV = normpdf(xnorV,mx,sdx);
yyV = normpdf(xxV,mx,sdx);
NyV = n*yyV/sum(yyV);
maxNy=max(NyV);
NnorV = fnorV * (maxNy / fnorV(round(nresol/2))); 
