function mutV=mutinfHisPro(xV,tauV,b,ioxV,ixV)
% mutV=mutinfHisPro(xV,tauV,b,ioxV,ixV)
% mutinfHisPro computes the mutual information on the time series 'xV' 
% for given delays in 'tauV'. The estimation of mutual information is 
% based on 'b' partitions of equal probability at each dimension. 
% The last two input parameters are the ordered time series and the
% corresponding indices that will be used in the equiprobable binning 
% (they both have been computed before and therefore they are passed 
% here rather than computing it again).

n = length(xV);
ntau = length(tauV);
mutV = NaN*ones(ntau,1);
hM = NaN*ones(b,b);
cumhM = zeros(b,b+1);  
cpxV = [1/b:1/b:1]';
for itau=1:ntau
    tau = tauV(itau);
    ntotal = n-tau;    
    rxV = [0;round(cpxV*ntotal)];
    ix1V = ixV;
    ix1V(ioxV(end-tau+1:end)) = [];
    x2prV = prctile(xV(ix1V+tau),cpxV*100);
    for i = 1:b
        for j = 1:b
            cumhM(i,j+1) = length(find(xV(ix1V(rxV(i)+1:rxV(i+1))+tau)<=x2prV(j)));
        end
        hM(i,:) = diff(cumhM(i,:));
    end
    % The use of formula H(x)=1, when log_b is used.
    mutS = 2;
    for j=1:b
        for i=1:b
            if hM(i,j) > 0
                mutS=mutS+(hM(i,j)/ntotal)*log(hM(i,j)/ntotal)/log(b);
            end
        end
    end 
    mutV(itau) = mutS;
end
